.. _admin:

Admin
*****

The data in the screenshots of the admin mimics the `RSS feed sample <https://help.apple.com/itc/podcasts_connect/#/itcbaf351599>`_ of the Podcasts Connect documentation.

App
===

.. image:: _static/img/admin-app.png

Shows
=====

List view
---------

.. image:: _static/img/admin-show-list.png

Change view
-----------

.. image:: _static/img/admin-show-change.png

Episodes
========

List view
---------

.. image:: _static/img/admin-episode-list.png

Change view
-----------

.. image:: _static/img/admin-episode-change.png


Enclosures
==========

List view
---------

.. image:: _static/img/admin-enclosure-list.png

Change view
-----------

.. image:: _static/img/admin-enclosure-change.png


Categories
==========

List view
---------

.. image:: _static/img/admin-category-list.png

Change view
-----------

.. image:: _static/img/admin-category-change.png


Speakers
========

List view
---------

.. image:: _static/img/admin-speaker-list.png

Change view
-----------

.. image:: _static/img/admin-speaker-change.png
